@@ -38,7 +38,7 @@ const QDBusArgument &operator>>(const QDBusArgument &argument, Stream &stream)
     return argument;
 }
 
-const QDBusArgument &operator>>(const QDBusArgument &argument, QVector<Stream> &stream)
+const QDBusArgument &operator>>(const QDBusArgument &argument, QList<Stream> &stream)
 {
     argument.beginArray();
     while ( !argument.atEnd() ) {
@@ -87,7 +87,7 @@ RecordMe::RecordMe(QObject* parent)
     }
 
     qDBusRegisterMetaType<Stream>();
-    qDBusRegisterMetaType<QVector<Stream>>();
+    qDBusRegisterMetaType<QList<Stream>>();
 
     m_durationTimer->setSingleShot(true);
 }
@@ -104,10 +104,15 @@ void RecordMe::init(const QDBusObjectPath& path)
         } else {
             cursor_mode = Hidden;
         }
-        const QVariantMap sourcesParameters = {{QLatin1String("handle_token"), m_handleToken},
-                                               {QLatin1String("types"), iface->availableSourceTypes()},
-                                               {QLatin1String("multiple"), false}, // for now?
-                                               {QLatin1String("cursor_mode"), uint(cursor_mode)}};
+        QVariantMap sourcesParameters = {{QLatin1String("handle_token"), m_handleToken},
+                                         {QLatin1String("types"), iface->availableSourceTypes()},
+                                         {QLatin1String("multiple"), false}, // for now?
+                                         {QLatin1String("cursor_mode"), uint(cursor_mode)},
+                                         {QLatin1String("persist_mode"), uint(m_persistMode)}};
+
+        if (!m_restoreToken.isEmpty()) {
+            sourcesParameters[QLatin1String("restore_token")] = m_restoreToken;
+        }
 
         auto reply = iface->SelectSources(m_path, sourcesParameters);
         reply.waitForFinished();
@@ -129,9 +134,13 @@ void RecordMe::response(uint code, const QVariantMap& results)
         return;
     }
 
+    if (results.contains(QLatin1String("restore_token"))) {
+        qDebug() << "Restore token:" << results[QLatin1String("restore_token")].toString();
+    }
+
     const auto streamsIt = results.constFind(QStringLiteral("streams"));
     if (streamsIt != results.constEnd()) {
-        QVector<Stream> streams;
+        QList<Stream> streams;
         streamsIt->value<QDBusArgument>() >> streams;
 
         handleStreams(streams);
@@ -168,7 +177,7 @@ void RecordMe::start()
     qDebug() << "started!" << reply.value().path();
 }
 
-void RecordMe::handleStreams(const QVector<Stream> &streams)
+void RecordMe::handleStreams(const QList<Stream> &streams)
 {
     const QVariantMap startParameters = {
         { QLatin1String("handle_token"), m_handleToken }
@@ -190,12 +199,29 @@ void RecordMe::handleStreams(const QVector<Stream> &streams)
         for (auto root : roots) {
             auto mo = root->metaObject();
             qDebug() << "feeding..." << stream.id << fd;
-            mo->invokeMethod(root, "addStream", Q_ARG(QVariant, QVariant::fromValue<quint32>(stream.id)), Q_ARG(QVariant, m_handleToken), Q_ARG(QVariant, fd));
+            mo->invokeMethod(root,
+                             "addStream",
+                             Q_ARG(QVariant, QVariant::fromValue<quint32>(stream.id)),
+                             Q_ARG(QVariant, m_handleToken),
+                             Q_ARG(QVariant, fd),
+                             Q_ARG(QVariant, true));
         }
     }
 }
 
+void RecordMe::setPersistMode(PersistMode persistMode)
+{
+    m_persistMode = persistMode;
+}
+
+void RecordMe::setRestoreToken(const QString &restoreToken)
+{
+    m_restoreToken = restoreToken;
+}
+
 void RecordMe::setDuration(int duration)
 {
     m_durationTimer->setInterval(duration);
 }
+
+#include "moc_RecordMe.cpp"
